diff --git a/public/invoice-view.js b/public/invoice-view.js
index dcc84ce..f7fe985 100644
--- a/public/invoice-view.js
+++ b/public/invoice-view.js
@@ -239,14 +239,14 @@ function renderInvoiceRow(invoice) {
paidBtn = ``;
}
// Send status button — only for QBO invoices
let sendBtn = '';
- if (hasQbo && !paid) {
+ if (hasQbo && !paid && !partial) {
const isSent = invoice.email_status === 'sent';
if (isSent) {
- sendBtn = `✉️ Sent`;
+ sendBtn = `Sent`;
} else {
- sendBtn = ``;
+ sendBtn = ``;
}
}
@@ -239,14 +239,14 @@ function renderInvoiceRow(invoice) {
paidBtn = ``;
}
- // Send status button — only for QBO invoices
+ // Send status — only for QBO invoices not yet paid/partial
let sendBtn = '';